Pootle Documentation — Pootle 2.5.1 documentation

# Pootle Documentation

Pootle is an online tool that makes the process of translating so much simpler. It allows crowd-sourced translations, easy volunteer contribution and gives statistics about the ongoing work.

Pootle is built using the powerful API of the Translate Toolkit and the Django framework. If you want to know more about these, you can dive into their own documentation.

- Translate Toolkit Documentation
- Django Documentation

## All you need to know

The following pages cover the documentation of Pootle from a wide variety of perspectives, including user’s, server administrator’s, and developer’s view.

- User’s guide
  - Getting started
  - Administration
- Features
  - Backends and storage
  - Online translation editor
  - Administrative features
- Administering a server
  - Installation
  - Upgrading
  - Performance tuning and managing the server
- Developers
  - Contributing
  - Pootle Development Roadmap
  - Hacking
  - Customizing the look
  - Testing
  - Release Process
  - Glossary
  - Styleguide
  - Making a Pootle Release
- Pootle API
  - Enabling the Pootle API
  - Pootle API usage
  - Available resources

## Additional Notes

- Changelog
- Release Notes
- External documentation
- License